@@ -1,3 +1,25 @@
+/*
+ * gedit-message-bus.h
+ * This file is part of gedit
+ *
+ * Copyright (C) 2008-2010 - Jesse van den Kieboom
+ *
+ * gedit is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * gedit is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with gedit; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ */
+
 #include "gedit-message-bus.h"
 
 #include <string.h>
@@ -8,7 +30,7 @@
  * GeditMessageCallback:
  * @bus: the #GeditMessageBus on which the message was sent
  * @message: the #GeditMessage which was sent
- * @userdata: the supplied user data when connecting the callback
+ * @user_data: the supplied user data when connecting the callback
  *
  * Callback signature used for connecting callback functions to be called
  * when a message is received (see gedit_message_bus_connect()).
@@ -58,7 +80,7 @@
  * static void
  * example_method_cb (GeditMessageBus *bus,
  *                    GeditMessage    *message,
- *                    gpointer         userdata)
+ *                    gpointer         user_data)
  * {
  * 	gchar *arg1 = NULL;
  *	
@@ -110,7 +132,7 @@ typedef struct
 
 	GDestroyNotify destroy_data;
 	GeditMessageCallback callback;
-	gpointer userdata;
+	gpointer user_data;
 } Listener;
 
 typedef struct
@@ -152,7 +174,7 @@ static void
 listener_free (Listener *listener)
 {
 	if (listener->destroy_data)
-		listener->destroy_data (listener->userdata);
+		listener->destroy_data (listener->user_data);
 
 	g_free (listener);
 }
@@ -264,7 +286,7 @@ gedit_message_bus_class_init (GeditMessageBusClass *klass)
 			      1,
 			      GEDIT_TYPE_MESSAGE_TYPE);
 
-	g_type_class_add_private (object_class, sizeof(GeditMessageBusPrivate));
+	g_type_class_add_private (object_class, sizeof (GeditMessageBusPrivate));
 }
 
 static Message *
@@ -310,7 +332,7 @@ static guint
 add_listener (GeditMessageBus      *bus,
 	      Message		   *message,
 	      GeditMessageCallback  callback,
-	      gpointer		    userdata,
+	      gpointer		    user_data,
 	      GDestroyNotify        destroy_data)
 {
 	Listener *listener;
@@ -319,7 +341,7 @@ add_listener (GeditMessageBus      *bus,
 	listener = g_new (Listener, 1);
 	listener->id = ++bus->priv->next_id;
 	listener->callback = callback;
-	listener->userdata = userdata;
+	listener->user_data = user_data;
 	listener->blocked = FALSE;
 	listener->destroy_data = destroy_data;
 
@@ -390,7 +412,7 @@ dispatch_message_real (GeditMessageBus *bus,
 		Listener *listener = (Listener *)item->data;
 		
 		if (!listener->blocked)
-			listener->callback (bus, message, listener->userdata);
+			listener->callback (bus, message, listener->user_data);
 	}
 }
 
@@ -468,7 +490,7 @@ process_by_match (GeditMessageBus      *bus,
 	          const gchar          *object_path,
 	          const gchar          *method,
 	          GeditMessageCallback  callback,
-	          gpointer              userdata,
+	          gpointer              user_data,
 	          MatchCallback         processor)
 {
 	Message *message;
@@ -487,7 +509,7 @@ process_by_match (GeditMessageBus      *bus,
 		Listener *listener = (Listener *)item->data;
 		
 		if (listener->callback == callback && 
-		    listener->userdata == userdata)
+		    listener->user_data == user_data)
 		{
 			processor (bus, message, item);
 			return;
@@ -523,7 +545,7 @@ gedit_message_bus_init (GeditMessageBus *self)
  *
  * Get the default application #GeditMessageBus.
  *
- * Return value: the default #GeditMessageBus
+ * Return value: (transfer full): the default #GeditMessageBus
  *
  */
 GeditMessageBus *
@@ -757,9 +779,9 @@ gedit_message_bus_unregister_all (GeditMessageBus *bus,
  *
  */
 gboolean
-gedit_message_bus_is_registered (GeditMessageBus	*bus,
-				 const gchar	*object_path,
-				 const gchar	*method)
+gedit_message_bus_is_registered (GeditMessageBus  *bus,
+				 const gchar	  *object_path,
+				 const gchar      *method)
 {
 	gchar *identifier;
 	gboolean ret;
@@ -778,7 +800,7 @@ gedit_message_bus_is_registered (GeditMessageBus	*bus,
 typedef struct
 {
 	GeditMessageBusForeach func;
-	gpointer userdata;
+	gpointer user_data;
 } ForeachInfo;
 
 static void
@@ -787,15 +809,15 @@ foreach_type (const gchar      *key,
 	      ForeachInfo      *info)
 {
 	gedit_message_type_ref (message_type);
-	info->func (message_type, info->userdata);
+	info->func (message_type, info->user_data);
 	gedit_message_type_unref (message_type);
 }
 
 /**
  * gedit_message_bus_foreach:
  * @bus: the #GeditMessagebus
- * @func: the callback function
- * @userdata: the user data to supply to the callback function
+ * @func: (scope call): the callback function
+ * @user_data: the user data to supply to the callback function
  *
  * Calls @func for each message type registered on the bus
  *
@@ -803,9 +825,9 @@ foreach_type (const gchar      *key,
 void 
 gedit_message_bus_foreach (GeditMessageBus        *bus,
 			   GeditMessageBusForeach  func,
-			   gpointer		   userdata)
+			   gpointer		   user_data)
 {
-	ForeachInfo info = {func, userdata};
+	ForeachInfo info = {func, user_data};
 	
 	g_return_if_fail (GEDIT_IS_MESSAGE_BUS (bus));
 	g_return_if_fail (func != NULL);
@@ -819,8 +841,8 @@ gedit_message_bus_foreach (GeditMessageBus        *bus,
  * @object_path: the object path
  * @method: the method
  * @callback: function to be called when message @method at @object_path is sent
- * @userdata: userdata to use for the callback
- * @destroy_data: function to evoke with @userdata as argument when @userdata
+ * @user_data: user_data to use for the callback
+ * @destroy_data: function to evoke with @user_data as argument when @user_data
  *                needs to be freed
  *
  * Connect a callback handler to be evoked when message @method at @object_path
@@ -834,7 +856,7 @@ gedit_message_bus_connect (GeditMessageBus	*bus,
 		           const gchar		*object_path,
 		           const gchar		*method,
 		           GeditMessageCallback  callback,
-		           gpointer		 userdata,
+		           gpointer		 user_data,
 		           GDestroyNotify	 destroy_data)
 {
 	Message *message;
@@ -847,7 +869,7 @@ gedit_message_bus_connect (GeditMessageBus	*bus,
 	/* lookup the message and create if it does not exist yet */
 	message = lookup_message (bus, object_path, method, TRUE);
 	
-	return add_listener (bus, message, callback, userdata, destroy_data);
+	return add_listener (bus, message, callback, user_data, destroy_data);
 }
 
 /**
@@ -872,11 +894,11 @@ gedit_message_bus_disconnect (GeditMessageBus *bus,
  * @bus: a #GeditMessageBus
  * @object_path: the object path
  * @method: the method
- * @callback: the connected callback
- * @userdata: the userdata with which the callback was connected
+ * @callback: (scope call): the connected callback
+ * @user_data: the user_data with which the callback was connected
  *
  * Disconnects a previously connected message callback by matching the 
- * provided callback function and userdata. See also 
+ * provided callback function and user_data. See also 
  * gedit_message_bus_disconnect().
  *
  */
@@ -885,11 +907,11 @@ gedit_message_bus_disconnect_by_func (GeditMessageBus      *bus,
 				      const gchar	   *object_path,
 				      const gchar	   *method,
 				      GeditMessageCallback  callback,
-				      gpointer		    userdata)
+				      gpointer		    user_data)
 {
 	g_return_if_fail (GEDIT_IS_MESSAGE_BUS (bus));
 	
-	process_by_match (bus, object_path, method, callback, userdata, remove_listener);
+	process_by_match (bus, object_path, method, callback, user_data, remove_listener);
 }
 
 /**
@@ -915,10 +937,10 @@ gedit_message_bus_block (GeditMessageBus *bus,
  * @bus: a #GeditMessageBus
  * @object_path: the object path
  * @method: the method
- * @callback: the callback to block
- * @userdata: the userdata with which the callback was connected
+ * @callback: (scope call): the callback to block
+ * @user_data: the user_data with which the callback was connected
  *
- * Blocks evoking the callback that matches provided @callback and @userdata.
+ * Blocks evoking the callback that matches provided @callback and @user_data.
  * Unblock the callback using gedit_message_unblock_by_func().
  *
  */
@@ -927,11 +949,11 @@ gedit_message_bus_block_by_func (GeditMessageBus      *bus,
 				 const gchar	      *object_path,
 				 const gchar	      *method,
 				 GeditMessageCallback  callback,
-				 gpointer	       userdata)
+				 gpointer	       user_data)
 {
 	g_return_if_fail (GEDIT_IS_MESSAGE_BUS (bus));
 	
-	process_by_match (bus, object_path, method, callback, userdata, block_listener);
+	process_by_match (bus, object_path, method, callback, user_data, block_listener);
 }
 
 /**
@@ -956,10 +978,10 @@ gedit_message_bus_unblock (GeditMessageBus *bus,
  * @bus: a #GeditMessageBus
  * @object_path: the object path
  * @method: the method
- * @callback: the callback to block
- * @userdata: the userdata with which the callback was connected
+ * @callback: (scope call): the callback to block
+ * @user_data: the user_data with which the callback was connected
  *
- * Unblocks the callback that matches provided @callback and @userdata.
+ * Unblocks the callback that matches provided @callback and @user_data.
  *
  */
 void
@@ -967,11 +989,11 @@ gedit_message_bus_unblock_by_func (GeditMessageBus      *bus,
 				   const gchar	        *object_path,
 				   const gchar	        *method,
 				   GeditMessageCallback  callback,
-				   gpointer	         userdata)
+				   gpointer	         user_data)
 {
 	g_return_if_fail (GEDIT_IS_MESSAGE_BUS (bus));
 	
-	process_by_match (bus, object_path, method, callback, userdata, unblock_listener);
+	process_by_match (bus, object_path, method, callback, user_data, unblock_listener);
 }
 
 static gboolean
@@ -1000,10 +1022,12 @@ send_message_real (GeditMessageBus *bus,
 						   g_object_ref (message));
 
 	if (bus->priv->idle_id == 0)
+	{
 		bus->priv->idle_id = g_idle_add_full (G_PRIORITY_HIGH,
 						      (GSourceFunc)idle_dispatch,
 						      bus,
 						      NULL);
+	}
 }
 
 /**
@@ -1124,16 +1148,16 @@ gedit_message_bus_send (GeditMessageBus *bus,
  * @bus: a #GeditMessageBus
  * @object_path: the object path
  * @method: the method
- * @...: NULL terminated list of key/value pairs
+ * @...: (allow-none): %NULL terminated list of key/value pairs
  *
  * This provides a convenient way to quickly send a message @method at 
  * @object_path synchronously over the bus. The variable argument list 
  * specifies key (string) value pairs used to construct the message 
  * arguments. To send a message asynchronously use gedit_message_bus_send().
  *
- * Return value: the constructed #GeditMessage. The caller owns a reference
- *               to the #GeditMessage and should call g_object_unref() when
- *               it is no longer needed
+ * Return value: (allow-none) (transfer full): the constructed #GeditMessage.
+ *               The caller owns a reference to the #GeditMessage and should
+ *               call g_object_unref() when it is no longer needed.
  */
 GeditMessage *
 gedit_message_bus_send_sync (GeditMessageBus *bus,
@@ -1155,4 +1179,4 @@ gedit_message_bus_send_sync (GeditMessageBus *bus,
 	return message;
 }
 
-// ex:ts=8:noet:
+/* ex:ts=8:noet: */
