@@ -54,8 +54,8 @@ enum
 	TAB_REMOVED,
 	SWITCH_TAB,
 	TAB_CLOSE_REQUEST,
-	TAB_DETACHED,
-	TABS_REORDERED,
+	CREATE_WINDOW,
+	PAGE_REORDERED,
 	SHOW_POPUP_MENU,
 	LAST_SIGNAL
 };
@@ -177,26 +177,27 @@ gedit_multi_notebook_class_init (GeditMultiNotebookClass *klass)
 			      2,
 			      GEDIT_TYPE_NOTEBOOK,
 			      GEDIT_TYPE_TAB);
-	signals[TAB_DETACHED] =
-		g_signal_new ("tab-detached",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GeditMultiNotebookClass, tab_detached),
-			      NULL, NULL,
-			      gedit_marshal_VOID__OBJECT_OBJECT,
-			      G_TYPE_NONE,
-			      2,
-			      GEDIT_TYPE_NOTEBOOK,
-			      GEDIT_TYPE_TAB);
-	signals[TABS_REORDERED] =
-		g_signal_new ("tabs-reordered",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GeditMultiNotebookClass, tabs_reordered),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
+	signals[CREATE_WINDOW] =
+		g_signal_new ("create-window",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (GeditMultiNotebookClass, create_window),
+		              NULL, NULL,
+		              gedit_marshal_OBJECT__OBJECT_OBJECT_INT_INT,
+		              GTK_TYPE_NOTEBOOK, 4,
+		              GEDIT_TYPE_NOTEBOOK, GTK_TYPE_WIDGET,
+		              G_TYPE_INT, G_TYPE_INT);
+	signals[PAGE_REORDERED] =
+		g_signal_new ("page-reordered",
+		              G_OBJECT_CLASS_TYPE (object_class),
+		              G_SIGNAL_RUN_FIRST,
+		              G_STRUCT_OFFSET (GeditMultiNotebookClass, page_reordered),
+		              NULL, NULL,
+		              gedit_marshal_VOID__OBJECT_OBJECT_INT,
+		              G_TYPE_NONE,
+		              3,
+		              GEDIT_TYPE_NOTEBOOK, GTK_TYPE_WIDGET,
+		              G_TYPE_INT);
 	signals[SHOW_POPUP_MENU] =
 		g_signal_new ("show-popup-menu",
 			      G_OBJECT_CLASS_TYPE (object_class),
@@ -251,20 +252,29 @@ notebook_tab_close_request (GeditNotebook      *notebook,
 		       notebook, tab);
 }
 
-static void
-notebook_tab_detached (GeditNotebook      *notebook,
-		       GeditTab           *tab,
-		       GeditMultiNotebook *mnb)
+static GtkNotebook *
+notebook_create_window (GeditNotebook      *notebook,
+			GtkWidget          *child,
+			gint                x,
+			gint                y,
+			GeditMultiNotebook *mnb)
 {
-	g_signal_emit (G_OBJECT (mnb), signals[TAB_DETACHED], 0,
-		       notebook, tab);
+	GtkNotebook *dest_notebook;
+
+	g_signal_emit (G_OBJECT (mnb), signals[CREATE_WINDOW], 0,
+	               notebook, child, x, y, &dest_notebook);
+
+	return dest_notebook;
 }
 
 static void
-notebook_tabs_reordered (GeditNotebook      *notebook,
-			 GeditMultiNotebook *mnb)
+notebook_page_reordered (GeditNotebook      *notebook,
+		         GtkWidget          *child,
+		         guint               page_num,
+		         GeditMultiNotebook *mnb)
 {
-	g_signal_emit (G_OBJECT (mnb), signals[TABS_REORDERED], 0);
+	g_signal_emit (G_OBJECT (mnb), signals[PAGE_REORDERED], 0, notebook,
+	               child, page_num);
 }
 
 static void
@@ -389,12 +399,12 @@ connect_notebook_signals (GeditMultiNotebook *mnb,
 			  G_CALLBACK (notebook_switch_page),
 			  mnb);
 	g_signal_connect (notebook,
-			  "tabs-reordered",
-			  G_CALLBACK (notebook_tabs_reordered),
+			  "page-reordered",
+			  G_CALLBACK (notebook_page_reordered),
 			  mnb);
 	g_signal_connect (notebook,
-			  "tab-detached",
-			  G_CALLBACK (notebook_tab_detached),
+			  "create-window",
+			  G_CALLBACK (notebook_create_window),
 			  mnb);
 	g_signal_connect (notebook,
 			  "tab-close-request",
@@ -418,9 +428,9 @@ disconnect_notebook_signals (GeditMultiNotebook *mnb,
 					      mnb);
 	g_signal_handlers_disconnect_by_func (notebook, notebook_page_removed,
 					      mnb);
-	g_signal_handlers_disconnect_by_func (notebook, notebook_tabs_reordered,
+	g_signal_handlers_disconnect_by_func (notebook, notebook_page_reordered,
 					      mnb);
-	g_signal_handlers_disconnect_by_func (notebook, notebook_tab_detached,
+	g_signal_handlers_disconnect_by_func (notebook, notebook_create_window,
 					      mnb);
 	g_signal_handlers_disconnect_by_func (notebook, notebook_tab_close_request,
 					      mnb);
